unit PermanentDMUnit;

interface

uses
  SysUtils, Classes, SxPmtDataModule, SxProvider, SxIconList, Menus,
  SxPopupMenu, SxNameSpaceUtils;

type
  TPermanentModule = class(TSxPermanentModule)
    SxSimpleTreeProvider1: TSxSimpleTreeProvider;
    SmallIconList: TSxIconList;
    LargeIconList: TSxIconList;
    BackgroundMenu: TSxPopupMenu;
    BackgroundMenuItem1: TMenuItem;
    FileMenu: TSxGrainMenu;
    ShellPlusItem1: TSxGrainMenuItem;
    procedure SxSimpleTreeProvider1GrainOpen(Sender: TSxCustomProvider;
      DataGrain: TSxCustomDataGrain; var CommandString, Parameters,
      Directory: WideString);
    procedure SxSimpleTreeProvider1GetInfoTip(Sender: TSxCustomProvider;
      DataGrain: TSxCustomDataGrain; var InfoTip: WideString);
    procedure BackgroundMenuItem1Click(Sender: TObject);
    procedure SxSimpleTreeProvider1GetGrainFileInfo(
      Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
      var FileInfo: TSxFileInfoDescriptor);
    procedure SxSimpleTreeProvider1GetGrainFileContents(
      Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
      Stream: TMemoryStream);
    procedure SxSimpleTreeProvider1GrainMoved(Sender: TSxCustomProvider;
      DataGrains: TSxDataGrainList);
    procedure ShellPlusItem1ClickGrainList(Sender: TSxMenuItem;
      DataGrainList: TSxDataGrainList);
    procedure SxSimpleTreeProvider1NewGrainFromStream(
      Sender: TSxCustomProvider; FolderGrain: TSxCustomDataGrain;
      FileInfo: TSxFileInfoDescriptor; FileData: TStream);
    procedure SxSimpleTreeProvider1RenameDataGrain(
      Sender: TSxCustomProvider; ParentGrain,
      DataGrain: TSxCustomDataGrain; var NewName: WideString;
      var PerformRename: Boolean);
    procedure SxSimpleTreeProvider1NewGrainFromFile(
      Sender: TSxCustomProvider; FolderGrain: TSxCustomDataGrain;
      FileName: WideString; var NewGrain: TSxCustomDataGrain);
  private
    { Private declarations }
    function GetGrainText(Grain:TSxCustomDataGrain):String;
  public
    { Public declarations }
  end;

var
  PermanentModule: TPermanentModule;

implementation

uses
  Dialogs;

{$R *.dfm}

procedure TPermanentModule.SxSimpleTreeProvider1GrainOpen(
  Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
  var CommandString, Parameters, Directory: WideString);
begin
  CommandString:='explorer.exe';
  Parameters:=DataGrain.Strings[0];
end;

procedure TPermanentModule.SxSimpleTreeProvider1GetInfoTip(
  Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
  var InfoTip: WideString);
begin
  InfoTip:='Info: '+InfoTip;
end;

procedure TPermanentModule.BackgroundMenuItem1Click(Sender: TObject);
begin
  ShowMessage('Background Menu Click');
end;

procedure TPermanentModule.SxSimpleTreeProvider1GetGrainFileInfo(
  Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
  var FileInfo: TSxFileInfoDescriptor);
begin
  if DataGrain.GrainType=gtItem then
  begin
    FileInfo.FileName:=ChangeFileExt(DataGrain.Name,'.url');
    FileInfo.FileSize:=Length(GetGrainText(DataGrain));
  end;
end;

function TPermanentModule.GetGrainText(Grain: TSxCustomDataGrain): String;
begin
  Result:='[InternetShortcut]'+#13#10+'URL='+Grain.Strings[0];
end;

procedure TPermanentModule.SxSimpleTreeProvider1GetGrainFileContents(
  Sender: TSxCustomProvider; DataGrain: TSxCustomDataGrain;
  Stream: TMemoryStream);
var
  url:String;
begin
  url:=GetGrainText(DataGrain);
  Stream.Write(url[1],Length(url));
end;

procedure TPermanentModule.SxSimpleTreeProvider1GrainMoved(
  Sender: TSxCustomProvider; DataGrains: TSxDataGrainList);
var
  i:Integer;
begin
  for i:=0 to DataGrains.Count-1 do
      TSxSimpleTreeProvider(Sender).DeletePermanentGrain(DataGrains[i]);
end;

procedure TPermanentModule.ShellPlusItem1ClickGrainList(Sender: TSxMenuItem;
  DataGrainList: TSxDataGrainList);
var
  TempLinks:TStrings;
  i:Integer;
begin
  TempLinks:=TStringList.Create;
  try
    for i:=0 to DataGrainList.Count-1 do
        TempLinks.Add(DataGrainList[i].Strings.Text);
    ShowMessage(TempLinks.Text);
  finally
    TempLinks.Free;
  end;
end;

procedure TPermanentModule.SxSimpleTreeProvider1NewGrainFromStream(
  Sender: TSxCustomProvider; FolderGrain: TSxCustomDataGrain;
  FileInfo: TSxFileInfoDescriptor; FileData: TStream);
var
  PermanentFolder:TSxSimpleTreeDataGrain;
  NewGrain:TSxSimpleTreeDataGrain;
begin
  PermanentFolder:=TSxSimpleTreeProvider(Sender).LocatePermanentGrain(TSxSimpleTreeDataGrain(FolderGrain).GUID);
  PermanentFolder.CreateNewChild(NewGrain);
  PermanentFolder.Add(NewGrain);
  NewGrain.Name:=FileInfo.FileName;
  NewGrain.GrainType:=gtItem;
end;

procedure TPermanentModule.SxSimpleTreeProvider1RenameDataGrain(
  Sender: TSxCustomProvider; ParentGrain, DataGrain: TSxCustomDataGrain;
  var NewName: WideString; var PerformRename: Boolean);
begin
  ShowMessage('New name '+NewName);
end;

procedure TPermanentModule.SxSimpleTreeProvider1NewGrainFromFile(
  Sender: TSxCustomProvider; FolderGrain: TSxCustomDataGrain;
  FileName: WideString; var NewGrain: TSxCustomDataGrain);
var
  PermanentFolder:TSxSimpleTreeDataGrain;
  tempChild:TSxSimpleTreeDataGrain;
begin
  PermanentFolder:=TSxSimpleTreeProvider(Sender).LocatePermanentGrain(TSxSimpleTreeDataGrain(FolderGrain).GUID);
  PermanentFolder.CreateNewChild(tempChild);
  NewGrain:=tempChild;
  PermanentFolder.Add(NewGrain as TSxSimpleTreeDataGrain);
  NewGrain.Name:=ExtractFileName(FileName);
  NewGrain.GrainType:=gtItem;
end;

initialization
  RegisterPermanentModuleClass(TPermanentModule);

end.
